Contributions (``taurex.contributions``)
========================================

Classes related to the computation of the optical depth

Base Contribution
-----------------

.. automodule:: taurex.contributions.contribution
   :members:
   :undoc-members:
   :show-inheritance:

Absorption
-----------

.. autoclass:: taurex.contributions.absorption.AbsorptionContribution
   :members:
   :undoc-members:
   :show-inheritance:

CIA
---

.. automodule:: taurex.contributions.cia
   :members:
   :undoc-members:
   :show-inheritance:


Rayleigh
--------

.. automodule:: taurex.contributions.rayleigh
   :members:
   :undoc-members:
   :show-inheritance:


SimpleClouds
----------------------------------------

.. automodule:: taurex.contributions.simpleclouds
   :members:
   :undoc-members:
   :show-inheritance:

Mie Scattering (BH)
----------------------------------------

.. warning::
   This is no longer available in the base TauREx 3 since version 3.1.
   To use this you must install the ``taurex_bhmie`` plugin.


Mie Scattering (Lee)
----------------------------------------

.. automodule:: taurex.contributions.leemie
   :members:
   :undoc-members:
   :show-inheritance:

Mie Scattering (Flat)
----------------------------------------

.. automodule:: taurex.contributions.flatmie
   :members:
   :undoc-members:
   :show-inheritance:
